@@ -5,7 +5,7 @@ import "git.sr.ht/~rockorager/go-jmap"
 type SortComparator struct {
 	Property string `json:"property,omitempty"`
 
-	IsAscending bool `json:"isAscending,omitempty"`
+	IsAscending bool `json:"isAscending"`
 
 	Collation jmap.CollationAlgo `json:"collation,omitempty"`
 }
